<?php
// $Id: ink.drush.inc,v 1.1.2.1 2010/08/19 19:49:28 mverbaar Exp $

/**
 * Implementation of hook_drush_command().
 */
function ink_drush_command() {
  $items = array();

  $items['ink'] = array(
    'description' => 'Set up an Ink Ribbon starter kit.',
    'arguments' => array(
      'name' => 'A name for your theme.',
    ),
    'options' => array(
      'machinename' => '[a-z, 0-9] A machine-readable name for your theme.',
      'sass' => '[y/n] Want SASS?',
    ),
    'examples' => array(
      'drush ink "My theme"',
    ),
  );

  return $items;
}

/**
 * Command: set up an Ink Ribbon starter kit.
 */
function drush_ink($name = 'My theme') {

  $machine_name = drush_get_option('machinename');
  $machine_name = ($machine_name) ? $machine_name : preg_replace('/[^a-z0-9]+/', '', strtolower($name));

  $sass = drush_get_option('sass');
  $sass = ($sass == 'y' || $sass == 'n') ? $sass : 'y';

  $kit = ($sass == 'y') ? 'STARTERKIT_SASS' : 'STARTERKIT';

  $inkribbon_path = drush_locate_root() . '/' . drupal_get_path('theme', 'inkribbon');
  // Navigate to parent directory.
  $inkribbon_path = split('/', $inkribbon_path);
  array_pop($inkribbon_path);
  $inkribbon_path = join('/', $inkribbon_path);
  // ... and again to determine the sub theme path.
  $subtheme_path = split('/', $inkribbon_path);
  array_pop($subtheme_path);
  $subtheme_path = join('/', $subtheme_path) . '/' . $machine_name;

  // Make a fresh copy of the starter kit and rename things where applicable.
  drush_op('ink_copy', $inkribbon_path . '/' . $kit, $subtheme_path, '/^(\.(\.)?|CVS|SVN|\.DS_Store|\.sass-cache)$/');
  drush_op('rename', $subtheme_path . '/' . $kit . '.info.txt', $subtheme_path . '/' . $machine_name . '.info');
  drush_op('ink_file_str_replace', $subtheme_path . '/' . $machine_name . '.info', 'name = ' . $kit, 'name = ' . $name);

  // Notify user of the newly created theme.
  drush_print(dt('Starter kit for !name created in !path.',
    array(
      '!name' => $name,
      '!path' => $subtheme_path,
    )));
}

/**
 * Copy a directory recursively.
 */
function ink_copy($source_dir, $target_dir, $ignore = '/^\.(\.)?$/') {
  if (!is_dir($source_dir)) {
    drush_die(dt('The directory !directory was not found.', array('!directory' => $source_dir)));
  }
  $dir = opendir($source_dir);
  @mkdir($target_dir);
  while($file = readdir($dir)) {
    if (!preg_match($ignore, $file)) {
      if (is_dir($source_dir . '/' . $file)) {
        ink_copy($source_dir . '/' . $file, $target_dir . '/' . $file, $ignore);
      }
      else {
        copy($source_dir . '/' . $file, $target_dir . '/' . $file);
      }
    }
  }
  closedir($dir);
}

/**
 * Replace strings in file contents.
 */
function ink_file_str_replace($file_path, $find, $replace) {
  $file_contents = file_get_contents($file_path);
  $file_contents = str_replace($find, $replace, $file_contents);
  file_put_contents($file_path, $file_contents);
}
