<?php
// $Id: template.php,v 1.1.2.1 2010/08/19 18:09:33 mverbaar Exp $

/**
 * Implementation of hook_theme().
 */
function inkribbon_theme(&$existing, $type, $theme, $path) {
  global $theme_key;
  $themes = list_themes();

  // Get settings from the active (sub) theme's info file.
  $settings = !empty($themes[$theme_key]->info['settings']) ? $themes[$theme_key]->info['settings'] : array();
  variable_set('theme_' . $theme_key . '_settings', $settings);

  // If the active theme has been loaded, force a refresh of Drupal internals.
  if (!empty($GLOBALS['theme_key'])) {
    theme_get_setting('', TRUE);
  }

  return array();
}

/**
 * Process variables for block.tpl.php.
 */
function inkribbon_preprocess_block(&$vars) {
  $vars['classes'] = 'block block-' . $vars['block']->module;
}

/**
 * Process variables for comment.tpl.php.
 */
function inkribbon_preprocess_comment(&$vars) {
  $classes = array(
    'comment',
    $status,
  );
  if ($vars['comment']->new) {
    $classes[] = 'comment-new';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for node.tpl.php.
 */
function inkribbon_preprocess_node(&$vars) {
  $classes = array(
    'node',
    'node-' . $vars['node']->type,
  );
  if ($vars['teaser']) {
    $classes[] = 'node-teaser';
  }
  if ($vars['sticky']) {
    $classes[] = 'node-sticky';
  }
  if (!$vars['status']) {
    $classes[] = 'node-unpublished';
  }
  $vars['classes'] = join(' ', $classes);
}

/**
 * Process variables for page.tpl.php.
 */
function inkribbon_preprocess_page(&$vars) {
  // Use h1 for the site name when the content title is empty.
  $vars['site_name_wrapper'] = ($vars['title']) ? 'div' : 'h1';

  // We apply an ImageCache preset to the logo, or just create the image
  // element with proper width/height attributes if no preset is found.
  if ($vars['logo']) {
    $logo_preset = theme_get_setting('logo_imagecache_preset');
    // Make the URL relative to the base path so image formatting functions
    // below can swallow it.
    $logo_path = preg_replace('#^' . preg_quote(base_path()) . '#', '', $vars['logo']);
    $logo_alt = t('!sitename logo', array('!sitename' => $vars['site_name']));

    if (module_exists('imagecache') && !empty($logo_preset) && count(imagecache_preset_by_name($logo_preset))) {
      $vars['logo'] = theme('imagecache', $logo_preset, $logo_path, $logo_alt);
    }
    else {
      $vars['logo'] = theme('image', $logo_path, $logo_alt);
    }
  }
}

/**
 * Return a themed form element.
 *
 * Overridden to remove the colons that are appended to form labels by default.
 */
function inkribbon_form_element($element, $value) {
  // This is also used in the installer, pre-database setup.
  $t = get_t();

  $output = '<div class="form-item"';
  if (!empty($element['#id'])) {
    $output .= ' id="' . $element['#id'] . '-wrapper"';
  }
  $output .= ">\n";

  // Construct the label.
  if (!empty($element['#title'])) {
    $title = $element['#title'];

    $required = '';
    if (!empty($element['#required'])) {
      $required = ' <span class="form-required" title="' . $t('This field is required.') . '">*</span>';
    }

    $attributes = '';
    if (!empty($element['#id'])) {
      $attributes = ' for="' . $element['#id'] . '"';
    }

    $output .= ' <label' . $attributes . '>' . filter_xss_admin($title) . $required . "</label>\n";
  }

  $output .= " $value\n";

  if (!empty($element['#description'])) {
    $output .= ' <div class="description">' . $element['#description'] . "</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}
